@@ -539,10 +539,9 @@ let lam_of_loc kind loc =
   | Loc_FILE -> Lconst (Const_immstring file)
   | Loc_MODULE ->
     let filename = Filename.basename file in
-    let module_name =
-      try String.capitalize (Filename.chop_extension filename)
-      with Invalid_argument _ -> "//"^filename^"//"
-    in Lconst (Const_immstring module_name)
+    let name = Env.get_unit_name () in
+    let module_name = if name = "" then "//"^filename^"//" else name in
+    Lconst (Const_immstring module_name)
   | Loc_LOC ->
     let loc = Printf.sprintf "File %S, line %d, characters %d-%d"
         file lnum cnum enum in
