@@ -153,7 +153,12 @@ linking with this library automatically adds back the
 options as if they had been provided on the
 command line, unless the
 .B \-noautolink
-option is given.
+option is given. Additionally, a substring
+.B $CAMLORIGIN
+inside a
+.BR \ \-ccopt
+options will be replaced by the full path to the .cma library,
+excluding the filename.
 .TP
 .B \-absname
 Show absolute filenames in error messages.
@@ -260,9 +265,9 @@ If the given directory starts with
 .BR + ,
 it is taken relative to the
 standard library directory. For instance,
-.B \-I\ +camlp4
+.B \-I\ +compiler-libs
 adds the subdirectory
-.B camlp4
+.B compiler-libs
 of the standard library to the search path.
 .TP
 .BI \-impl \ filename
@@ -299,6 +304,9 @@ Recognize file names ending with
 as interface files (instead of the default .mli).
 .TP
 .B \-keep-locs
+Keep documentation strings in generated .cmi files.
+.TP
+.B \-keep-locs
 Keep locations in generated .cmi files.
 .TP
 .B \-labels
@@ -595,7 +603,8 @@ compiling your program with later versions of OCaml when they add new
 warnings or modify existing warnings.
 
 The default setting is
-.B \-warn\-error\ -a (all warnings are non-fatal).
+.B \-warn\-error \-a
+(all warnings are non-fatal).
 .TP
 .B \-warn\-help
 Show the description of all available warning numbers.
