@@ -61,7 +61,9 @@ let x_p_dll = "%.p"-.-ext_dll;;
 (* -output-obj targets *)
 let x_byte_c = "%.byte.c";;
 let x_byte_o = "%.byte"-.-ext_obj;;
+let x_byte_so = "%.byte"-.-ext_dll;;
 let x_native_o = "%.native"-.-ext_obj;;
+let x_native_so = "%.native"-.-ext_dll;;
 
 rule "target files"
   ~dep:"%.itarget"
@@ -221,6 +223,15 @@ rule "ocaml: cmo* -> byte.c"
   ~dep:"%.cmo"
   (Ocaml_compiler.byte_output_obj "%.cmo" x_byte_c);;
 
+rule "ocaml: cmo* -> byte.(so|dll|dylib)"
+  ~prod:x_byte_so
+  ~dep:"%.cmo"
+  ~doc:"The foo.byte.so target, or foo.byte.dll under Windows, \
+  or foo.byte.dylib under Mac OS X will produce a shared library file
+  by passing the -output-obj and -cclib -shared options \
+  to the OCaml compiler. See also foo.native.{so,dll,dylib}."
+  (Ocaml_compiler.byte_output_shared "%.cmo" x_byte_so);;
+
 rule "ocaml: p.cmx* & p.o* -> p.native"
   ~prod:"%.p.native"
   ~deps:["%.p.cmx"; x_p_o]
@@ -239,6 +250,11 @@ rule "ocaml: cmx* & o* -> native.(o|obj)"
   ~deps:["%.cmx"; x_o]
   (Ocaml_compiler.native_output_obj "%.cmx" x_native_o);;
 
+rule "ocaml: cmx* & o* -> native.(so|dll|dylib)"
+  ~prod:x_native_so
+  ~deps:["%.cmx"; x_o]
+  (Ocaml_compiler.native_output_shared "%.cmx" x_native_so);;
+
 rule "ocaml: mllib & d.cmo* -> d.cma"
   ~prod:"%.d.cma"
   ~dep:"%.mllib"
@@ -527,11 +543,22 @@ end;;
 flag ["ocaml"; "ocamlyacc"] (atomize !Options.ocaml_yaccflags);;
 flag ["ocaml"; "menhir"] (atomize !Options.ocaml_yaccflags);;
 flag ["ocaml"; "doc"] (atomize !Options.ocaml_docflags);;
+flag ["ocaml"; "ocamllex"] (atomize !Options.ocaml_lexflags);;
 
 (* Tell menhir to explain conflicts *)
 flag [ "ocaml" ; "menhir" ; "explain" ] (S[A "--explain"]);;
+flag [ "ocaml" ; "menhir" ; "infer" ] (S[A "--infer"]);;
 
-flag ["ocaml"; "ocamllex"] (atomize !Options.ocaml_lexflags);;
+(* Define two ocamlbuild flags [only_tokens] and [external_tokens(Foo)]
+   which correspond to menhir's [--only-tokens] and [--external-tokens Foo].
+   When they are used, these flags should be passed both to [menhir] and to
+   [menhir --raw-depend]. *)
+let () =
+  List.iter begin fun mode ->
+    flag [ mode; "only_tokens" ] (S[A "--only-tokens"]);
+    pflag [ mode ] "external_tokens" (fun name ->
+      S[A "--external-tokens"; A name]);
+  end [ "menhir"; "menhir_ocamldep" ];;
 
 (* Tell ocamllex to generate ml code *)
 flag [ "ocaml" ; "ocamllex" ; "generate_ml" ] (S[A "-ml"]);;
@@ -558,6 +585,15 @@ let () =
     (* Ocamlfind will link the archives for us. *)
     flag ["ocaml"; "link"; "program"] & A"-linkpkg";
     flag ["ocaml"; "link"; "toplevel"] & A"-linkpkg";
+    flag ["ocaml"; "link"; "output_obj"] & A"-linkpkg";
+
+    (* "program" will make sure that -linkpkg is passed when compiling
+       whole-programs (.byte and .native); but it is occasionally
+       useful to pass -linkpkg when building archives for example
+       (.cma and .cmxa); the "linkpkg" flag allows user to request it
+       explicitly. *)
+    flag ["ocaml"; "link"; "linkpkg"] & A"-linkpkg";
+    pflag ["ocaml"; "link"] "dontlink" (fun pkg -> S[A"-dontlink"; A pkg]);
 
     let all_tags = [
       ["ocaml"; "byte"; "compile"];
@@ -616,6 +652,8 @@ let () =
     (fun param -> S [A "-open"; A param]);
   pflag ["ocaml"; "compile"] "open"
     (fun param -> S [A "-open"; A param]);
+  pflag ["ocaml"; "link"] "runtime_variant"
+    (fun param -> S [A "-runtime-variant"; A param]);
   ()
 
 let camlp4_flags camlp4s =
@@ -666,8 +704,11 @@ flag ["ocaml"; "debug"; "pack"; "byte"] (A "-g");;
 flag ["ocaml"; "debug"; "compile"; "native"] (A "-g");;
 flag ["ocaml"; "debug"; "link"; "native"; "program"] (A "-g");;
 flag ["ocaml"; "debug"; "pack"; "native"] (A "-g");;
+flag ["c";     "debug"; "compile"] (A "-g");
+flag ["c";     "debug"; "link"] (A "-g");
 flag ["ocaml"; "link"; "native"; "output_obj"] (A"-output-obj");;
 flag ["ocaml"; "link"; "byte"; "output_obj"] (A"-output-obj");;
+flag ["ocaml"; "link"; "output_shared"] & (S[A"-cclib"; A"-shared"]);;
 flag ["ocaml"; "dtypes"; "compile"] (A "-dtypes");;
 flag ["ocaml"; "annot"; "compile"] (A "-annot");;
 flag ["ocaml"; "annot"; "pack"] (A "-annot");;
@@ -694,6 +735,7 @@ flag ["ocaml"; "compile"; "no_alias_deps";] (A "-no-alias-deps");;
 flag ["ocaml"; "compile"; "strict_formats";] (A "-strict-formats");;
 flag ["ocaml"; "native"; "compile"; "opaque";] (A "-opaque");;
 flag ["ocaml"; "native"; "compile"; "no_float_const_prop";] (A "-no-float-const-prop");
+flag ["ocaml"; "compile"; "keep_docs";] (A "-keep-docs");
 flag ["ocaml"; "compile"; "keep_locs";] (A "-keep-locs");
 flag ["ocaml"; "absname"; "compile"] (A "-absname");;
 flag ["ocaml"; "absname"; "infer_interface"] (A "-absname");;
