@@ -1268,7 +1268,12 @@ sscanf "Hello \n" "%s%s%_1[ ]\n" (fun s1 s2 ->
  sscanf "Hello\nWorld!" "%s\n%s%!" (fun s1 s2 ->
       s1 = "Hello" && s2 = "World!") &&
  sscanf "Hello\nWorld!" "%s\n%s@!%!" (fun s1 s2 ->
-      s1 = "Hello" && s2 = "World")
+      s1 = "Hello" && s2 = "World") &&
+ (* PR#6791 *)
+ sscanf "Hello{foo}" "%s@{%s" (fun s1 s2 ->
+   s1 = "Hello" && s2 = "foo}") &&
+ sscanf "Hello[foo]" "%s@[%s" (fun s1 s2 ->
+   s1 = "Hello" && s2 = "foo]")
 ;;
 
 test (test52 ())
