@@ -251,15 +251,17 @@ let match_printer_type ppf desc =
   let printer_type_new = printer_type ppf "printer_type_new" in
   let printer_type_old = printer_type ppf "printer_type_old" in
   Ctype.init_def(Ident.current_time());
-  match extract_target_parameters desc.val_type with
-  | None ->
-     (try
-        (match_simple_printer_type ppf desc printer_type_new, false)
-      with Ctype.Unify _ ->
-        (match_simple_printer_type ppf desc printer_type_old, true))
-  | Some (path, args) ->
-     (* only 'new' style is available for generic printers *)
-     match_generic_printer_type ppf desc path args printer_type_new, false
+  try
+    (match_simple_printer_type ppf desc printer_type_new, false)
+  with Ctype.Unify _ ->
+    try
+      (match_simple_printer_type ppf desc printer_type_old, true)
+    with Ctype.Unify _ as exn ->
+      match extract_target_parameters desc.val_type with
+      | None -> raise exn
+      | Some (path, args) ->
+          (match_generic_printer_type ppf desc path args printer_type_new,
+           false)
 
 let find_printer_type ppf lid =
   try
